
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import { ConfigProvider, Space, Collapse, Tag, Modal, message, Checkbox, Button, Row, Col, Input, Segmented, DatePicker } from 'antd';
import { PostRoleAddpermission, getPermissionListWithchilds, getRoleGetpermissions } from '@/apis/api';
import { CheckBox } from 'docx';


const selectfieldNames = { label: 'name', value: 'id' };


const PagesMainPermissionRoleDispense: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState(null)
    const [selectedIds, setSelectedIds] = useState<number[]>([]);
    const [collapseKey, setCollapseKey] = useState<string[]>([]);


    useEffect(() => {
        setOpenPreview(openModel.openDispenseModal)
    }, [openModel.openDispenseModal])

    const handleChange = (tag: number, checked: boolean) => {
        const nextSelectedTags = checked
            ? [...selectedIds, tag]
            : selectedIds.filter((t) => t !== tag);
        setSelectedIds(nextSelectedTags);
    };

    // 递归函数用于收集所有权限ID
    function collectAllPermissionIds(permission) {
        let ids = [permission.id];
        if (permission.childs && Array.isArray(permission.childs)) {
            permission.childs.forEach(child => {
                ids = ids.concat(collectAllPermissionIds(child));
            });
        }
        return ids;
    }
    // 检查给定的 id 是否存在于 res.data 中，并返回对应的下标加 1
    function checkIdInData(ids, data) {
        const result = [];
        ids.forEach(id => {
            const index = data.findIndex(item => item.id === id);
            if (index !== -1) {
                result.push((index + 1).toString());
            }
        });

        // 去重
        const uniqueResult = [...new Set(result)];
        return uniqueResult;
    }
    return (
        <>
            <ConfigProvider
                theme={{

                }}
            >
                <Modal
                    open={openPreview}
                    centered
                    maskClosable={false}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/openExportModal', payload: false })
                    }}
                    afterOpenChange={async (open) => {
                        if (open) {
                            let res = await getPermissionListWithchilds()
                            setDetail(res.data)
                            let resrole = await getRoleGetpermissions({ ids: id })
                            const nextSelectedTags = resrole.data.permissions.flatMap(permission =>
                                collectAllPermissionIds(permission)
                            );
                            setSelectedIds(nextSelectedTags);
                            const uniqueIndexes = checkIdInData(nextSelectedTags, res.data.permissions);
                            console.log(uniqueIndexes); // 输出去重后的结果
                            // 设置状态
                            setCollapseKey(uniqueIndexes);
                        }
                    }}
                    onOk={async () => {

                    }}
                >
                    {detail && collapseKey.length > 0 &&
                        <>
                            <Space direction="vertical">
                                {
                                    detail && detail.permissions.map((item: any, index: number) => (
                                        <>

                                            <Collapse
                                                defaultActiveKey={collapseKey}
                                                items={[
                                                    {
                                                        key: (index + 1).toString(),
                                                        label: (<>{item.name}</>),
                                                        children: (
                                                            <>
                                                                <Row gutter={[16, 16]}>
                                                                    <>
                                                                        <Col span={6} style={{ display: 'flex', justifyContent: 'flex-start', alignItems: 'center' }}>
                                                                            <Tag.CheckableTag checked={selectedIds.includes(item.id)} onChange={(checked) => { handleChange(item.id, checked) }}>{item.name}</Tag.CheckableTag>
                                                                        </Col>
                                                                        <Col span={18}>
                                                                            <Row gutter={[16, 16]}>
                                                                                {
                                                                                    item.childs && item.childs.length > 0 && item.childs.map((itemChild: any) => (
                                                                                        <>
                                                                                            <Col span={6} style={{ display: 'flex', justifyContent: 'flex-start', alignItems: 'center' }}>
                                                                                                <Tag.CheckableTag checked={selectedIds.includes(itemChild.id)} onChange={(checked) => { handleChange(itemChild.id, checked) }}>{itemChild.name}</Tag.CheckableTag>
                                                                                            </Col>
                                                                                            <Col span={18} style={{ display: 'flex', justifyContent: 'flex-start', alignItems: 'center' }}>
                                                                                                <Row gutter={[16, 16]}>
                                                                                                    {
                                                                                                        itemChild.childs && itemChild.childs.length > 0 && itemChild.childs.map((itemThird: any) => (
                                                                                                            <>
                                                                                                                <Col>
                                                                                                                    <Tag.CheckableTag checked={selectedIds.includes(itemThird.id)} onChange={(checked) => { handleChange(itemThird.id, checked) }}>{itemThird.name}</Tag.CheckableTag>
                                                                                                                </Col>
                                                                                                            </>
                                                                                                        ))
                                                                                                    }
                                                                                                </Row>
                                                                                            </Col>
                                                                                        </>
                                                                                    ))
                                                                                }
                                                                            </Row>
                                                                        </Col>
                                                                    </>
                                                                </Row>
                                                            </>
                                                        ),
                                                    },
                                                ]}
                                            />



                                        </>


                                    ))

                                }
                            </Space>


                        </>
                    }

                </Modal>
            </ConfigProvider >
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainPermissionRoleDispense);